.. _system-requirements:

===================
System Requirements
===================

Supported Operating Systems
---------------------------

Skyline's source install supports the following host Operating Systems (OS):

- Ubuntu Focal (20.04)
